OC.L10N.register(
    "settings",
    {
    "Private" : "Zasebno",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Vidno le uporabnikom povezanimi s programom Talk prek telefonske številke.",
    "Local" : "Krajevno",
    "Only visible to people on this instance and guests" : "Vidno le krajevnim uporabnikom in povezanim gostom",
    "Federated" : "Zvezno",
    "Only synchronize to trusted servers" : "Usklajuj le z zaupanja vrednimi strežniki",
    "Published" : "Objavljeno",
    "Synchronize to trusted servers and the global and public address book" : "Usklajuj z varnimi strežniki in splošnimi in javnimi imeniki",
    "Verify" : "Overi",
    "Verifying …" : "Poteka overjanje ...",
    "Unable to change password" : "Ni mogoče spremeniti gesla",
    "Very weak password" : "Zelo šibko geslo",
    "Weak password" : "Slabo geslo",
    "So-so password" : "Šibko geslo",
    "Good password" : "Dobro geslo",
    "Strong password" : "Odlično geslo",
    "Groups" : "Skupine",
    "Group list is empty" : "Seznam skupin je prazen",
    "Unable to retrieve the group list" : "Ni mogoče pridobiti seznama skupin",
    "{actor} added you to group {group}" : "{actor} vas doda v skupino {group}",
    "You added {user} to group {group}" : "Uporabnika {user} dodate v skupino {group}",
    "{actor} added {user} to group {group}" : "{actor} doda uporabnika {user} v skupino {group}",
    "An administrator added you to group {group}" : "Skrbnik vas doda v skupino {group}",
    "An administrator added {user} to group {group}" : "Skrbnik doda uporabnika {user} v skupino {group}",
    "{actor} removed you from group {group}" : "{actor} vas odstrani iz skupine {group}",
    "You removed {user} from group {group}" : "Uporabnika {user} odstranite iz skupine {group}",
    "{actor} removed {user} from group {group}" : "{actor} odstrani uporabnika {user} iz skupine {group}",
    "An administrator removed you from group {group}" : "Skrbnik vas odstrani iz skupine {group}",
    "An administrator removed {user} from group {group}" : "Skrbnik odstrani uporabnika {user} iz skupine {group}",
    "Your <strong>group memberships</strong> were modified" : "Spremenjeno je vaše <strong>članstvo v skupinah</strong> ",
    "{actor} changed your password" : "{actor} spremeni moje geslo",
    "You changed your password" : "Spremenite geslo",
    "Your password was reset by an administrator" : "Skrbnik sistema ponastavi moje geslo",
    "Your password was reset" : "Geslo je bilo ponastavljeno",
    "{actor} changed your email address" : "{actor} spremeni moj elektronski naslov",
    "You changed your email address" : "Spremenite elektronski naslov",
    "Your email address was changed by an administrator" : "Skrbnik spremeni moj elektronski naslov",
    "You created an app password for a session named \"{token}\"" : "Ustvarili ste geslo programa za sejo »{token}«.",
    "An administrator created an app password for a session named \"{token}\"" : "Skrbnik je ustvaril geslo programa za sejo »{token}«.",
    "You deleted app password \"{token}\"" : "Izbrišete žeton gesla programa »{token}«",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Preimenujete žeton gesla programa »{token}« to »{newToken}«",
    "You granted filesystem access to app password \"{token}\"" : "Odobrite sistemski dostop do žetona gesla programa »{token}«",
    "You revoked filesystem access from app password \"{token}\"" : "Odobrite sistemski datotečni dostop gesla programa »{token}«",
    "Security" : "Varnostna opozorila",
    "You successfully logged in using two-factor authentication (%1$s)" : "Uspešno zabeležite uporabo dvo-stopenjske overitve (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Poskus prijave z dvostopenjsko overitvijo je spodletel (%1$s)",
    "Remote wipe was started on %1$s" : "Oddaljeno varnostno brisanje je bilo začeto na %1$s.",
    "Remote wipe has finished on %1$s" : "Oddaljeno varnostno brisanje je bilo končano na %1$s.",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Spremenjeno je bilo <strong>geslo</strong> oziroma <strong>elektronski naslov</strong>",
    "Settings" : "Nastavitve",
    "Could not remove app." : "Programa ni mogoče odstraniti.",
    "Could not update app." : "Programa ni mogoče posodobiti.",
    "Wrong password" : "Napačno geslo",
    "Unable to change personal password" : "Ni mogoče spremeniti osebnega gesla.",
    "Saved" : "Shranjeno",
    "No Login supplied" : "Ni podane prijave",
    "Unable to change password. Password too long." : "Gesla ni mogoče spremeniti. Geslo je predolgo.",
    "Authentication error" : "Napaka overjanja",
    "Please provide an admin recovery password; otherwise, all account data will be lost." : "Podati je treba skrbniško obnovitveno geslo, sicer bodo vsi uporabniški računi izgubljeni.",
    "Wrong admin recovery password. Please check the password and try again." : "Napačno navedeno skrbniško obnovitveno geslo. Preverite geslo in poskusite znova.",
    "Backend does not support password change, but the encryption of the account key was updated." : "Ozadnji program ne podpira spreminjanja gesla, je pa uspešno posodobljen šifrirni ključ računa.",
    "Administrator documentation" : "Skrbniška dokumentacija",
    "User documentation" : "Uporabniška dokumentacija",
    "Nextcloud help overview" : "Pregled pomoči Nextcloud",
    "Invalid SMTP password." : "Neveljavno geslo SMTP",
    "Email setting test" : "Preizkus nastavitev elektronske pošte",
    "Well done, %s!" : "Odlično, %s!",
    "If you received this email, the email configuration seems to be correct." : "Če ste to sporočilo prejeli, potem nastavitev pošte deluje pravilno.",
    "Email could not be sent. Check your mail server log" : "Elektronskega sporočila ni bilo mogoče poslati. Preverite dnevnik poštnega strežnika.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Med pošiljanjem sporočila se je prišlo do napake. Preverite nastavitve (napaka: %s).",
    "You need to set your account email before being able to send test emails. Go to %s for that." : "Pred preizkusnim pošiljanjem sporočil je treba nastaviti elektronski naslov uporabnika. To je mogoče med možnostmi %s.",
    "Recently active" : "Nedavna dejavnost",
    "Disabled accounts" : "Onemogočeni računi",
    "Invalid account" : "Neveljaven račun",
    "Invalid mail address" : "Neveljaven elektronski naslov",
    "Settings saved" : "Nastavitve so shranjene.",
    "Unable to change full name" : "Ni mogoče spremeniti polnega imena",
    "Unable to change email address" : "Ni mogoče spremeniti elektronskega naslova",
    "Unable to set invalid phone number" : "Ni mogoče nastaviti neveljavne telefonske številke",
    "Unable to set invalid website" : "Ni mogoče nastaviti neveljavnega spletnega mesta",
    "Some account data was invalid" : "Nekateri podatki računa niso veljavni",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Za overitev računa Twitter, objavite sporočilo (prepričajte se, da ni nobenega preloma vrstice):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Za overitev spletne strani, shranite navedeno vsebino v spletni korenski mapi v ».well-known/CloudIdVerificationCode.txt« (prepričajte se, da je celotno besedilo v eni vrstici): ",
    "%1$s changed your password on %2$s." : "%1$s spremeni vaše geslo %2$s.",
    "Your password on %s was changed." : "Vaše geslo %s je bilo spremenjeno.",
    "Your password on %s was reset by an administrator." : "Skrbnik je ponastavil vaše geslo %s.",
    "Your password on %s was reset." : "Geslo za %s je bilo ponastavljeno.",
    "Password for %1$s changed on %2$s" : "Geslo za %1$s je bilo spremenjeno %2$s",
    "Password changed for %s" : "Geslo za %s je spremenjeno",
    "If you did not request this, please contact an administrator." : "Če tega dejanja niste zahtevali, stopite nemudoma v stik s skrbnikom sistema.",
    "Your email address on %s was changed." : "Elektronski naslov za %s je spremenjen.",
    "Your email address on %s was changed by an administrator." : "Skrbnik je spremenil elektronski naslov za %s .",
    "Email address for %1$s changed on %2$s" : "Elektronski naslov računa %1$s je bil spremenjen %2$s.",
    "Email address changed for %s" : "Elektronski naslov za račun %s je spremenjen.",
    "The new email address is %s" : "Nov elektronski naslov je %s",
    "Your %s account was created" : "Račun %s je uspešno ustvarjen.",
    "Welcome aboard" : "Dobrodošli",
    "Welcome aboard %s" : "Dobrodošli %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Omogočen je vaš dostop do oblaka %s, v katerega lahko varno dodate podatke in jih posredujete v souporabo.",
    "Your Login is: %s" : "Dodeljeno prijavno ime je: %s",
    "Set your password" : "Določitev gesla",
    "Go to %s" : "Odpri oblak %s",
    "Install Client" : "Namesti odjemalca",
    "Apps" : "Programi",
    "Personal" : "Osebno",
    "Administration" : "Skrbništvo",
    "Users" : "Uporabniki",
    "Additional settings" : "Dodatne nastavitve",
    "Administration privileges" : "Skrbniška dovoljenja",
    "Groupware" : "Skupinsko delo",
    "Overview" : "Splošni pregled",
    "Basic settings" : "Osnovne nastavitve",
    "Sharing" : "Souporaba",
    "Availability" : "Razpoložljivost",
    "Calendar" : "Koledar",
    "Personal info" : "Osebni podatki",
    "Mobile & desktop" : "Mobilni in namizni dostop",
    "Artificial Intelligence" : "Umetna inteligenca",
    "Email server" : "Poštni strežnik",
    "Background jobs" : "Opravila v ozadju",
    "Unlimited" : "Neomejeno",
    "Verifying" : "Preverjanje",
    "Allowed admin IP ranges" : "Dovoljeni skrbniški obsegi naslovov IP",
    "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "Nastavitveni ključ »%1$s« zahteva podatkovno polje (zaznano je %2$s). Skrbniško preverjanje obsega naslovov IP ne bo uveljavljeno.",
    "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "Nastavitveni ključ »%1$s« vsebuje neveljaven obseg naslovov IP: »%2$s«",
    "Admin IP filtering is correctly configured." : "Skrbniško filtriranje naslovov IP je nastavljeno pravilno.",
    "App directories owner" : "Lastnik programskih map",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Nekatere mape programov imajo lastništvo določeno na uporabnika, ki ni spletni strežniški uporabnik. To se lahko zgodi, če so programi nameščeni ročno. Preveriti je treba dovoljenja map:\n%s",
    "App directories have the correct owner \"%s\"" : "Programske mape imajo določenega pravilnega lastnika »%s«.",
    "Brute-force Throttle" : "Zaščita pred vdorom z grobo silo",
    "Your remote address could not be determined." : "Oddaljenega naslova naprave ni mogoče določiti.",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Oddaljeni naslov je bil prepoznan kot »%s« in je trenutno zaščiten pred vdorom z grobo silo, kar upočasnjuje izvajanje različnih nalog. Če oddaljeni naslov ni vaš naslov, je to lahko znak, da posredniški strežnik ni pravilno nastavljen.",
    "Your remote address \"%s\" is not brute-force throttled." : "Oddaljeni naslov »%s« ni omejen z zaščito pred vdorom z grobo silo.",
    "Old administration imported certificates" : "Uvožena stara uporabniška potrdila",
    "A background job is pending that checks for administration imported SSL certificates. Please check back later." : "Na čakanju je ozadnje opravilo, ki preverja obstoj skrbniško uvožena potrdila SSL. Nastavitve preverite kasneje.",
    "There are some administration imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Shranjenih je nekaj potrdil SSL, ki z različico Nextcloud 21 ne bodo več v uporabi. Potrdila je mogoče uvoziti z ukazom »occ security:certificates:import«. Zabeležene poti v podatkovnem imeniku so izpisane spodaj.",
    "Code integrity" : "Celovitost kode",
    "Integrity checker has been disabled. Integrity cannot be verified." : "Preverjalnik celovitosti kode je onemogočen, zato podatkov ni mogoče preveriti.",
    "No altered files" : "Ni spremenjenih datotek",
    "Some files have not passed the integrity check. {link1} {link2}" : "Nekatere datoteke niso prestale preverjanja celovitosti. {link1} {link2}",
    "Cron errors" : "Napake Cron",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:\n%s" : "Ni mogoče izvesti opravila cron v vmesniku ukazne vrstice. Pojavile so se tehnične napake:\n%s",
    "The last cron job ran without errors." : "Zadnja opravila cron so bila izvedena brez napak.",
    "Cron last run" : "Zadnji zagon sistema cron",
    "Last background job execution ran %s. Something seems wrong. {link}." : "Zadnje opravilo v ozadju je bilo izvedeno %s. Kaže, da je z izvajanje nekaj narobe. {link}.",
    "Last background job execution ran %s." : "Zadnje opravilo v ozadju je bilo izvedeno %s.",
    "Data directory protected" : "Podatkovna mapa je zaščitena.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Podatkovna mapa in datoteke so najverjetneje dostopni na Internetu, ker datoteka .htaccess ni ustrezno nastavljena. Priporočljivo je nastaviti spletni strežnik tako, da dostop do mape z zunanjega omrežja ni mogoč, ali pa tako, da podatkovno mapo prestavite izven korenske mape strežnika.",
    "Could not check that the data directory is protected. Please check manually that your server does not allow access to the data directory." : "Ni mogoče preveriti, ali je podatkovna mapa zaščitena. Da je dostop do podatkovne mape onemogočen, bo treba preveriti ročno.",
    "Database missing columns" : "Podatkovni zbirki manjkajo stolpci",
    "Missing optional column \"%s\" in table \"%s\"." : "Manjka izbirni stolpec »%s« v razpredelnici »%s«.",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "V podatkovni zbirki manjka nekaj izbirnih stolpcev. Ker je dodajanje stolpcev na velikih razpredelnicah časovno izredno zahtevno opravilo, ta niso dodana samodejno, ker so v osnovi izbirna. Z ukazom »occ db:add-missing-columns« je stolpce mogoče varno dodati ročno med delovanjem sistema. Po dodajanju bo odzivnost in uporabnost nekaterih zmožnosti občutna izboljšana.",
    "Database missing indices" : "Podatkovni zbirki manjkajo kazala",
    "Missing indices:" : "Manjkajoča kazala:",
    "\"%s\" in table \"%s\"" : "»%s« v razpredelnici »%s«",
    "Database missing primary keys" : "Podatkovni zbirki manjkajo osnovni ključi",
    "Missing primary key on table \"%s\"." : "Manjka osnovni ključ v razpredelnici »%s«.",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "V podatkovni zbirki ni določenih nekaterih osnovnih ključev. Ker je dodajanje ključev na velikih razpredelnicah časovno izredno zahtevno opravilo, ti niso dodani samodejno. Z ukazom »occ db:add-missing-primary-keys« je ključe mogoče varno dodati ročno, medtem ko je sistem v delovanju.",
    "Database pending bigint migrations" : "Podatkovna zbirka je v pripravljenosti na izvedbo prenosa velikih števil.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "Nekateri stolpci v podatkovni zbirki so brez pretvornika velikih števil. Ker je spreminjanje vrste stolpcev v velikih razpredelnicah časovno izredno zahtevno opravilo, ti niso spremenjeni samodejno. Z ukazom »occ db:convert-filecache-bigint« je mogoče te spremembe dodati ročno. Opravilo je treba izvesti, ko okolje ni dejavno.",
    "Debug mode" : "Razhroščevalni način",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Program je zagnan v načinu za ugotavljanje napak. Možnost je priporočljivo omogočiti le za krajevne razvojne namestitve in ne za produkcijska okolja.",
    "Debug mode is disabled." : "Razhroščevalni način je onemogočen.",
    "Default phone region" : "Privzeto telefonsko območje",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "Med nastavitvami namestitve ni določenega privzetega telefonskega področja. To je pomembno za overjanje telefonskih številk brez uporabe kode države. Za vpis številk brez kode je treba dodati možnost »default_phone_region« z ustrezno kodo regije po določilih ISO 3166-1.",
    "Email test" : "Preizkus elektronske pošte",
    "Email test was successfully sent" : "Preizkusno sporočilo je bilo uspešno poslano.",
    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Ni še overjene nastavitve strežnika elektronske pošte. Te je mogoče prilagajati med »nastavitvami elektronske pošte«. Po spremembi uporabite gumb »Pošlji sporočilo« za dokončno overitev.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "Podatkovna zbirka se uporablja za transakcijsko zaklepanje datotek. Če želite povečati zmogljivost, prilagodite nastavitve pomnilnika memcache, če je ta na voljo.",
    "Forwarded for headers" : "Posredovano za glave",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "Nastavitev zaupanja v posredniške strežnike »trusted_proxies\" ni nastavljena pravilno. Zapisana mora biti kot polje vrednosti.",
    "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Nastavitev povratne posredovalniške glave ni pravilna. To predstavlja varnostno tveganje, ki lahko omogoči tretji osebi ponarediti naslov IP za dostop do okolja.",
    "Your IP address was resolved as %s" : "Naslov IP je bil razrešen kot %s",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Nastavitev povratne posredovalniške glave ni pravilna ali pa je v okolje Nextcloud omogočen dostop prek zaupanja vrednega strežnika. Če slednje ne drži, je to varnostno tveganje, ki lahko omogoči tretji osebi dostop do okolja.",
    "HTTPS access and URLs" : "Dostop HTTPS in naslovi URL",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Dostop do strani je omogočen pred nevarovanega protokola HTTP. Priporočljivo je na strežniku nastaviti uporabo HTTPS. Brez te nastavitve nekatere pomembne spletne možnosti, kot je »kopiranje v odložišče« in »storitve« ne bodo na voljo.",
    "Accessing site insecurely via HTTP." : "Povezava je vzpostavljena z nepreverjenim protokolom HTTP.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Dostop do okolja poteka prek varne povezave, a ta ustvarja ne-varne naslove URL. To verjetno pomeni, da je strežnik za povratnim strežnikom in da vrednosti nastavitev za prepisovanje niso pravilno nastavljene.",
    "Your instance is generating insecure URLs. If you access your instance over HTTPS, this likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Strežnik ustvarja nezanesljive naslove URL. Če do strežnika dostopite z uporabo protokola HTTPS, to verjetno pomeni, da je strežnik za povratnim posrednikom in da nastavljene vrednosti Nextcloud za prepisovanje niso pravilno nastavljene.",
    "Internet connectivity" : "Internetna povezljivost",
    "Internet connectivity is disabled in configuration file." : "Internetna povezljivost je v nastavitveni datoteki onemogočena.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Strežnik je brez vzpostavljene internetne povezave. Več končnih točk ni mogoče doseči. To pomeni, da priklapljanje zunanjih diskov,  opozorila za posodobitve in namestitve programske opreme iz drugih virov, ni mogoče. Oddaljen dostop do datotek in pošiljanje obvesti najverjetneje prav tako ne deluje. Vzpostavite povezavo, da omogočite vso funkcionalnost.",
    "JavaScript modules support" : "Podpora za module JavaScript",
    "Old server-side-encryption" : "Staro strežniško šifriranje",
    "Disabled" : "Onemogočeno",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Star način strežniškega šifriranja je še vedno omogočen. Priporočljivo je možnost izklopiti.",
    "Memcache" : "Memcache",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "Ni nastavljenega predpomnilnika. Za povečanje zmogljivosti je priporočljivo nastaviti vrednosti memcache, če je ta na voljo.",
    "Configured" : "Nastavljeno",
    "You are not using MySQL" : "Podatkovna zbirka MySQL ni v uporabi.",
    "MySQL Unicode support" : "Podpora za unikod MySQL",
    "Overwrite CLI URL" : "Prepiši naslov URL vmesnika ukazne vrstice",
    "PHP APCu configuration" : "Nastavitve PHP APCu",
    "PHP default charset" : "Privzeti znakovni nabor PHP",
    "PHP configuration option \"default_charset\" should be UTF-8" : "Nastavitvena možnost znakovnega nabora PHP »default_charset« mora biti UTF-8",
    "PHP set_time_limit" : "Možnost PHP set_time_limit",
    "The function is available." : "Zmožnost je na voljo",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Funkcija PHP »set_time_limit« ni na voljo. To lahko povzroči nepričakovano zaustavitev skriptnih ukazov med izvajanjem, kar lahko povzroči sesutje namestitve. To možnost je priporočeno omogočiti.",
    "Freetype" : "Freetype",
    "Supported" : "Podprto",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Namestitev PHP je brez ustrezne podpore za FreeType, kar pogosto vpliva na težave s slikami profila in nastavitvami vmesnika.",
    "PHP getenv" : "PHP getenv",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Kaže, da okolje PHP ni ustrezno nastavljeno za poizvedovanje sistemskih spremenljivk. Preizkus z ukazom getegetenv(\"PATH\") vrne le prazen odziv.",
    "PHP memory limit" : "Omejitev pomnilnika PHP",
    "PHP modules" : "Moduli PHP",
    "This instance is missing some required PHP modules. It is required to install them: %s." : "Namestitev PHP ne vključuje nekaterih priporočenih modulov. Priporočljivo jih je namestiti: %s.",
    "PHP opcache" : "Opcache PHP",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "Modul PHP OPcache ni naložen. Za najboljše delovanje je priporočljivo modul dodati k uporabljeni namestitvi PHP.",
    "OPcache is disabled. For better performance, it is recommended to apply \"opcache.enable=1\" to your PHP configuration." : "Možnost OPcache je onemogočena. Za najboljše delovanje je priporočljivo dodati možnost »opcache.enable=1« med nastavitve PHP.",
    "Correctly configured" : "Pravilno nastavljeno",
    "PHP version" : "Različica PHP",
    "You are currently running PHP %s." : "Trenutno je v uporabi različica PHP %s.",
    "PHP \"output_buffering\" option" : "MOžnost PHP »output_buffering«",
    "PHP configuration option \"output_buffering\" must be disabled" : "Nastavitvena možnost PHP »output_buffering« mora biti onemogočena.",
    "Push service" : "Potisne storitve",
    "Valid enterprise license" : "Veljavno poslovno dovoljenje",
    "Free push service" : "Proste potisne storitve",
    "Random generator" : "Ustvarjalnik naključnih vrednosti",
    "Secure" : "Varno",
    "Configuration file access rights" : "Dovoljenja dostopa do nastavitvene datoteke",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Nastavitve so nastavljene le za branje. To onemogoča prilagajanje prek spletnega vmesnika, prav tako je treba nastavitveno datoteko  vsakič znova ročno posodobiti.",
    "Nextcloud configuration file is writable" : "Nastavitvena datoteka Nextcloud je zapisljiva",
    "HTTP headers" : "Glave HTTP",
    "- The `%1$s` HTTP header is not set to `%2$s`. Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "– Glava HTTP »%1$s« ni nastavljena na pričakovano vrednost »%2$s«. Nekatere možnosti morda ne bodo delovale pravilno, zato je priporočljivo prilagoditi nastavitve.",
    "- The `%1$s` HTTP header is not set to `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "– Glava HTTP »%1$s« ni nastavljena na pričakovano vrednost »%2$s«. To predstavlja potencialno varnostno ali zasebnostno tveganje, zato je priporočljivo prilagoditi nastavitve.",
    "- The `%1$s` HTTP header is not set to `%2$s`, `%3$s`, `%4$s`, `%5$s` or `%6$s`. This can leak referer information. See the {w3c-recommendation}." : "– Glava HTTP »%1$s« ni nastavljena na »%2$s«, »%3$s«, »%4$s«, »%5$s« ali »%6$s«. To la hko povzroči spuščanje sklicnih podatkov. Več o tem je zapisano na {w3c-recommendation}.",
    "- The `Strict-Transport-Security` HTTP header is not set to at least `%d` seconds (current value: `%d`). For enhanced security, it is recommended to use a long HSTS policy." : "– Glava HTTP za varen prenos podatkov »Strict-Transport-Security« ni nastavljena na vsaj »%d« sekund (trenutna vrednost je »%d«). Za večjo varnost je priporočljivo omogočiti pravila HSTS.",
    "- The `Strict-Transport-Security` HTTP header is malformed: `%s`. For enhanced security, it is recommended to enable HSTS." : "– Glava HTTP za varen prenos podatkov »Strict-Transport-Security« je neustrezno oblikovana: »%s«. Za večjo varnost je priporočljivo omogočiti pravila HSTS.",
    "- The `Strict-Transport-Security` HTTP header is not set (should be at least `%d` seconds). For enhanced security, it is recommended to enable HSTS." : "– Glava HTTP za varen prenos podatkov »Strict-Transport-Security« ni nastavljena (biti bi morala na vsaj »%d« sekund). Za večjo varnost je priporočljivo omogočiti pravila HSTS.",
    "Some headers are not set correctly on your instance" : "Nekatere glave niso nastavljene na pravilen način.",
    "Database version" : "Različica podatkovne zbirke",
    "Unknown database platform" : "Neznano okolje podatkovne zbirke",
    "Architecture" : "Arhitektura",
    "64-bit" : "64-bitni",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!" : "Kaže, da je v uporabi 32-bitna različica PHP. Okolje Nextcloud zahteva za odzivno delovanje 64-bitno različico. Priporočljivo je nadgraditi operacijski sistem in PHP na zahtevano raven!",
    "Temporary space available" : "Razpoložljivost začasnega prostora",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Podatkovna zbirka ni zagnana na ravni »READ COMMITTED«. To lahko povzroči težave pri vzporednem izvajanju dejanj.",
    ".well-known URLs" : "Naslovi .well-known URL",
    "Profile information" : "Podrobnosti profila",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Slika profila, polno ime, elektronski naslov, telefonska številka, naslov, spletna stran, račun Twitter, ustanova, vloga, naslov, biografija in ali je profil omogočen.",
    "Nextcloud settings" : "Nastavitve Nextcloud",
    "Enable" : "Omogoči",
    "Machine translation" : "Strojno prevajanje",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Strojno prevajanje lahko izvajajo različni programi. Na tem mestu je mogoče določiti prednost uporabe programov za strojno prevajanje, ki so trenutno nameščeni v sistem.",
    "Image generation" : "Ustvarjanje slik",
    "Text processing" : "Obdelava besedila",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Obdelavo besedila lahko urejajo različni programi. Na tem mestu je mogoče določiti program za uporabo.",
    "Task:" : "Naloga:",
    "Here you can decide which group can access certain sections of the administration settings." : "Na tem mestu je mogoče določiti, katera skupina ima dostop do določenih možnosti skrbniških nastavitev.",
    "Unable to modify setting" : "Ni mogoče spremeniti nastavitve",
    "None" : "Brez",
    "Changed disclaimer text" : "Spremenjeno besedilo o omejitvi odgovornosti",
    "Deleted disclaimer text" : "Izbrisano besedilo o omejitvi odgovornosti",
    "Could not set disclaimer text" : "Ni mogoče določiti besedila o omejitvi odgovornosti",
    "Allow apps to use the Share API" : "Dovoli programom uporabo vmesnika API souporabe",
    "Allow resharing" : "Dovoli nadaljnje omogočanje souporabe",
    "Allow sharing with groups" : "Dovoli souporabo s skupinami",
    "Restrict users to only share with users in their groups" : "Uporabnikom dovoli omogočanje souporabe le znotraj njihove skupine",
    "Allow users to share via link and emails" : "Uporabnikom dovoli omogočanje souporabe s povezavami in z elektronskimi sporočili",
    "Allow public uploads" : "Dovoli javno pošiljanje datotek v oblak",
    "Always ask for a password" : "Vedno zahtevaj geslo",
    "Enforce password protection" : "Vsili zaščito z geslom",
    "Exclude groups from password requirements" : "Izloči skupine iz zahtev uporabe gesla",
    "Exclude groups from creating link shares" : "Onemogoči navedenim skupinam ustvarjanje povezav do mest uporabe",
    "Groups excluded from sharing" : "Skupine z onemogočeno souporabo s povezavo",
    "Enforce expiration date" : "Vsili datum preteka",
    "Expire shares after x days" : "Mesta souporabe naj potečejo po x dneh",
    "Set default expiration date for shares to other servers" : "Nastavi privzeti datuma poteka za mesta souporabe na drugih strežnikih",
    "Default expiration time of shares in days" : "Privzeti čas poteka za mesta souporabe v dnevih",
    "Privacy settings for sharing" : "Nastavitve zasebnosti za souporabo",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Pokaži izjavo o omejitvi odgovornosti pri uporabi javnih povezav za pošiljanje (če je onemogočen prikaz seznama datotek)",
    "Disclaimer text" : "Besedilo o omejitvi odgovornosti",
    "This text will be shown on the public link upload page when the file list is hidden." : "Besedilo izjave o omejitvi odgovornosti, ki bo izpisano v oknu za pošiljanje, ko je možnost prikaza seznama datotek onemogočena.",
    "Default share permissions" : "Privzeta dovoljenja souporabe",
    "Two-Factor Authentication" : "Dvo-stopenjska overitev",
    "Enforce two-factor authentication" : "Vsili dvo-stopenjsko overjanje",
    "Limit to groups" : "Omeji na skupine",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Vsiljeno dvo-stopenjsko overjanje je mogoče določiti le za določene skupine.",
    "Two-factor authentication is enforced for all members of the following groups." : "Dvo-stopenjsko overjanje je vsiljeno za vse člane navedenih skupin.",
    "Enforced groups" : "Obvezno za skupine",
    "Two-factor authentication is not enforced for members of the following groups." : "Dvo-stopenjsko overjanje ni obvezno za člane navedenih skupin.",
    "Excluded groups" : "Izločene skupine",
    "Save changes" : "Shrani spremembe",
    "Default" : "Privzeto",
    "Show details for {appName} app" : "Pokaži podrobnosti programa {appName}",
    "Update to {update}" : "Posodobi na različico {update}",
    "Remove" : "Odstrani",
    "Featured" : "Izbrano",
    "This app is supported via your current Nextcloud subscription." : "Program je podprt prek trenutne naročnine Nextcloud",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Uradne programe razvijajo posamezniki, ki sodelujejo s skupnostjo. Paketi vključujejo osrednje zmožnosti programa, uporaba pa je namenjena tudi končnim uporabnikom.",
    "Community rating: {score}/5" : "Ocena skupnosti: {score} / 5",
    "Disable all" : "Onemogoči vse",
    "Download and enable all" : "Prejmi in omogoči vse",
    "All apps are up-to-date." : "Vsi programi so posodobljeni.",
    "Icon" : "Ikona",
    "Name" : "Ime",
    "Version" : "Različica",
    "Level" : "Vloga",
    "Actions" : "Dejanja",
    "Results from other categories" : "Rezultati iskanja med drugimi kategorijami",
    "No apps found for your version" : "Za navedeni iskalni niz ni programov",
    "_%n app has an update available_::_%n apps have an update available_" : ["Na voljo je posodobitev za %n program.","Na voljo sta posodobitvi za %n programa.","Na voljo so posodobitve za %n programe.","Na voljo so posodobitve za %n programov."],
    "_Update_::_Update all_" : ["Posodobi","Posodobi","Posodobi","Posodobi vse"],
    "Failed to create group" : "Ustvarjanje skupine je spodletelo",
    "Creating group…" : "Poteka ustvarjanje skupine ...",
    "Create group" : "Ustvari skupino",
    "Group name" : "Ime skupine",
    "Please enter a valid group name" : "Vpisati je treba veljavno ime skupine",
    "Loading groups…" : "Poteka nalaganje skupin ...",
    "Could not load app discover section" : "Ni mogoče naložiti razdelka predstavitve programov",
    "Could not render element" : "Predmeta ni mogoče izrisati",
    "Nothing to show" : "Ni vsebine za prikaz",
    "Loading" : "Poteka nalaganje ...",
    "Fetching the latest news…" : "Poteka pridobivanje zadnjih novic ...",
    "Previous slide" : "Predhodni prikaz",
    "Next slide" : "Naslednji prikaz",
    "Choose slide to display" : "Izbor vsebine za prikaz",
    "{index} of {total}" : "{index} od {total}",
    "Daemon" : "Ozadnji program",
    "Type" : "Vrsta",
    "Learn more" : "Prikaži več",
    "Confirm" : "Potrdi",
    "Cancel" : "Prekliči",
    "Description" : "Opis",
    "View in store" : "Pokaži v trgovini",
    "Visit website" : "Odpri spletno stran",
    "Usage documentation" : "Dokumentacija uporabe",
    "Admin documentation" : "Skrbniška dokumentacija",
    "Developer documentation" : "Dokumentacija za razvijalce",
    "Details" : "Podrobnosti",
    "All" : "Vse",
    "Limit app usage to groups" : "Omeji uporabo programa na skupine",
    "No results" : "Ni zadetkov",
    "Update to {version}" : "Posodobi na različico {version}",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Programa ni mogoče namestiti zaradi nerazrešenih odvisnosti:",
    "Latest updated" : "Nazadnje posodobljeno",
    "Author" : "Avtor",
    "Categories" : "Kategorije",
    "Resources" : "Viri",
    "Documentation" : "Dokumentacija",
    "Interact" : "Interakcija",
    "Report a bug" : "Pošlji poročilo o hrošču",
    "Request feature" : "Predlagaj zmožnost",
    "Ask questions or discuss" : "Vključi se v pogovor",
    "Rate the app" : "Oceni program",
    "Rate" : "Oceni",
    "Changelog" : "Dnevnik sprememb",
    "Google Chrome for Android" : "Google Chrome za Android",
    "{productName} iOS app" : "{productName} za iOS",
    "{productName} Android app" : "{productName} za Android",
    "{productName} Talk for iOS" : "{productName} Talk za iOS",
    "{productName} Talk for Android" : "{productName} Talk za Android",
    "Sync client" : "Odjemalec za usklajevanje",
    "This session" : "Ta seja",
    "{client} - {version} ({system})" : "{client} – {version} ({system})",
    "{client} - {version}" : "{client} – {version}",
    "Device name" : "Ime naprave",
    "Cancel renaming" : "Prekliči preimenovanje",
    "Save new name" : "Shrani novo ime",
    "Marked for remote wipe" : "Označeno za oddaljeno varnostno brisanje",
    "Device settings" : "Nastavitve naprave",
    "Allow filesystem access" : "Dovoli dostop do datotečnega sistema",
    "Rename" : "Preimenuj",
    "Revoke" : "Prekliči",
    "Wipe device" : "Varnostno izbriši napravo",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Obnovitev tega žetona lahko prepreči varnostno brisanje naprave, če se to še ni začelo.",
    "Device" : "Naprava",
    "Last activity" : "Zadnja dejavnost",
    "Devices & sessions" : "Naprave in seje",
    "Web, desktop and mobile clients currently logged in to your account." : "Spletne, namizne in mobilne naprave, ki so trenutno povezane z računom.",
    "Error while creating device token" : " Napaka med ustvarjanjem žetona naprave",
    "App name" : "Ime programa",
    "Create new app password" : "Ustvari novo geslo programa",
    "App password copied!" : "Geslo programa je kopirano!",
    "Copy app password" : "Kopiraj geslo programa",
    "Login name copied!" : "Prijavno ime je kopirano!",
    "Copy login name" : "Kopiraj prijavno ime",
    "Could not copy app password. Please copy it manually." : "Gesla programa ni mogoče kopirati. Storite to ročno.",
    "Could not copy login name. Please copy it manually." : "Uporabniškega imena ni mogoče kopirati. Storite to ročno.",
    "New app password" : "Nogo geslo programa",
    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Uporabite poverila za nastavljanje programa ali naprave. Iz varnostnih razlogov bo geslo prikazano le enkrat.",
    "Login" : "Prijava",
    "Password" : "Geslo",
    "Show QR code for mobile apps" : "Pokaži kodo QR za mobilne programe",
    "Use system cron service to call the cron.php file every 5 minutes." : "Uporabljena je sistemska storitev »cron«, ki vzpostavi povezavo z datoteko cron.php vsakih 5 minut.",
    "The cron.php needs to be executed by the system account \"{user}\"." : "Datoteka cron.php mora biti izvedena s sistemskim računom »{user}«.",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "Za delovanje je zahtevana razširitev PHP POSIX. Več podrobnosti je zapisanih v {linkstart}dokumentaciji PHP{linkend}.",
    "Unable to update background job mode" : "Ni mogoče posodobiti načina poslov v ozadju.",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Za najboljše delovanje strežnika je pomembna ustrezna nastavitev opravil v ozadju. Pri večjih namestitvah je priporočljiva nastavitev »Cron«. Več podrobnosti je zapisanih v dokumentaciji.",
    "Last job execution ran {time}. Something seems wrong." : "Zadnji poskus izvedbe je bil izveden {time}. Kaže, da je šlo nekaj narobe.",
    "Last job ran {relativeTime}." : "Osvežitev je bila nazadnje izvedena {relativeTime}.",
    "Background job did not run yet!" : "Posel v ozadju še ni zagnan!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single account instance." : "Z vsako naloženo stranjo se izvede ena naloga. Možnost je priporočljivo uporabiti le za okolje z enim računom.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 accounts depending on the usage)." : "Osveževanje z datoteko cron.php omogoča storitev webcron in sicer vsakih 5 minut po protokolu HTTP. Možnost je uporabna za manjše število uporabnikov (1–5 računov in odvisno od načina rabe).",
    "Cron (Recommended)" : "Cron (priporočeno)",
    "Unable to update profile default setting" : "Ni mogoče posodobiti privzetih nastavitev profila",
    "Profile" : "Profil",
    "Enable or disable profile by default for new accounts." : "Omogoči oziroma onemogoči privzeti profil za nove račune.",
    "Failed to save setting" : "Shranjevanje nastavitve je spodletelo",
    "Unable to update server side encryption config" : "Ni mogoče posodobiti strežniških nastavitev šifriranja",
    "Server-side encryption" : "Šifriranje na strežniku",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Šifriranje na strežniku omogoča šifriranje datotek, poslanih na strežnik. Opravilo ima tudi omejitvene učinke, kot je vpliv na hitrost delovanja, Možnost je na voljo po potrebi.",
    "Enable server-side encryption" : "Omogoči šifriranje na strežniku",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Modul za šifriranje ni naložen. Pred nadaljevanjem je treba modul določiti v seznamu programov.",
    "Select default encryption module:" : "Izbor privzetega modula za šifriranje:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Preseliti je treba šifrirne ključe s starega sistema (ownCloud ≤ 8.0) na novega. Omogočite možnost »Privzeti šifrirni modul« in zaženite ukaz »{command}«.",
    "Enable encryption" : "Omogoči šifriranje",
    "Please read carefully before activating server-side encryption:" : "Pred omogočanjem strežniškega šifriranja pozorno preberite opombe:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Ko je šifriranje enkrat omogočeno, bodo v času manjše aktivnosti šifrirane vse datoteke, poslane na strežnik. Šifriranje bo mogoče izklopiti šele kasneje, če bo uporabljen šifrirni modul podpiral tovrstno funkcionalnost in bodo doseženi vsi ostali pogoji (na primer, ustrezno nastavljeni obnovitveni ključi).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Šifriranje samo po sebi še ne zagotavlja varnosti sistema. Več podorobnosti o delovanju programa in primeri uporabe so zabeleženi v dokumentaciji.",
    "Be aware that encryption always increases the file size." : " Upoštevajte, da šifriranje poveča velikost datoteke.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Priporočljivo je redno ustvarjati varnostne kopije podatkov, v primeru šifriranja pa varnostno kopirati tudi šifrirne ključe.",
    "This is the final warning: Do you really want to enable encryption?" : "To je zadnje opozorilo. Ali res želite omogočiti šifriranje?",
    "Please confirm the group removal" : "Potrditi je treba skupinsko odstranjevanje",
    "Submit" : "Pošlji",
    "Rename group" : "Preimenuj skupino",
    "Current password" : "Trenutno geslo",
    "New password" : "Novo geslo",
    "Change password" : "Spremeni geslo",
    "Choose your profile picture" : "Izbor slike profila",
    "Please select a valid png or jpg file" : "Izbrati je treba veljavno datoteko png ali jpg.",
    "Error setting profile picture" : "Napaka nastavljanja slike profila",
    "Error cropping profile picture" : "Napaka obrezovanja slike profila",
    "Error saving profile picture" : "Napaka shranjevanja slike profila",
    "Error removing profile picture" : "Napaka odstranjevanja slike profila",
    "Your profile picture" : "Slika profila",
    "Upload profile picture" : "Pošlji sliko profila",
    "Choose profile picture from Files" : "Izbor slike profila med datotekami",
    "Remove profile picture" : "Odstrani sliko profila",
    "The file must be a PNG or JPG" : "Datoteka mora biti v zapisu PNG ali JPG",
    "Picture provided by original account" : "Slika iz izvornega računa",
    "Set as profile picture" : "Nastavi sliko profila",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Upoštevajte, da lahko traja tudi 24 ur preden se slika profila posodobi na vseh mestih.",
    "Unable to update date of birth" : "Datuma rojstva ni mogoče posodobiti",
    "Enter your date of birth" : "Vpišite datum rojstva",
    "You are a member of the following groups:" : "Omogočeno je članstvo v skupinah:",
    "Your full name" : "Polno ime",
    "Email options" : "Možnosti elektronske pošte",
    "Options for additional email address {index}" : "Dodatni elektronski naslov {index}",
    "Remove primary email" : "Odstrani osnovni elektronski naslov",
    "Delete email" : "Izbriši elektronski naslov",
    "This address is not confirmed" : "Ta naslov ni potrjen",
    "Unset as primary email" : "Odstrani oznako osnovnega elektronskega naslova",
    "Set as primary email" : "Nastavi kot osnovni elektronski naslov",
    "Additional email address {index}" : "Dodatni elektronski naslov {index}",
    "Unable to delete primary email address" : "Ni mogoče izbrisati osnovnega elektronskega naslova",
    "Unable to update primary email address" : "Ni mogoče posodobiti osnovnega elektronskega naslova",
    "Unable to add additional email address" : "Ni mogoče dodati dodatnega elektronskega naslova",
    "Unable to update additional email address" : "Ni mogoče posodobiti dodatnega elektronskega naslova",
    "Unable to delete additional email address" : "Ni mogoče izbrisati dodatnega elektronskega naslova",
    "Primary email for password reset and notifications" : "Osnovni elektronski naslov za obnavljanje gesla in obvestila",
    "No email address set" : "Poštni naslov ni nastavljen",
    "Your handle" : "Ročnik",
    "Your headline" : "Vaš naslov",
    "Unable to update language" : "Ni mogoče posodobiti jezika",
    "Languages" : "Jeziki",
    "Help translate" : "Sodelujte pri prevajanju",
    "No language set" : "Jezik ni nastavljen",
    "Unable to update locale" : "Ni mogoče posodobiti jezikovnih nastavitev",
    "Locales" : "Jezikovne nastavitve",
    "Week starts on {firstDayOfWeek}" : "Prvi dan tedna je {firstDayOfWeek}",
    "No locale set" : "Ni določenih jezikovnih nastavitev",
    "Your city" : "Kraj bivanja",
    "Your organisation" : "Ustanova",
    "Your phone number" : "Osebna telefonska številka",
    "Edit your Profile visibility" : "Prilagodi vidnost profila",
    "Unable to update profile enabled state" : "Ni mogoče posodobiti omogočenega stanja profila",
    "Enable profile" : "Omogoči profil",
    "Unable to update visibility of {displayId}" : "Ni mogoče posodobiti vidnosti {displayId}",
    "Your role" : "Vloga",
    "Timezone" : "Časovni pas",
    "Your X (formerly Twitter) handle" : "Osebni ročnik X (prej Twitter)",
    "Your website" : "Osebna spletna stran",
    "Invalid value" : "Neveljavna vrednost",
    "Unable to update {property}" : "Lastnosti {property} ni mogoče posodobiti",
    "No {property} set" : "Lastnost {property} ni nastavljena",
    "Change scope level of {property}, current scope is {scope}" : "Spremenite raven obsega lastnosti {property}, trenutno je določena kot {scope}",
    "Unable to update federation scope of the primary {property}" : "Ni mogoče posodobiti obsega zveznosti osnovne lastnosti {property}",
    "Unable to update federation scope of additional {property}" : "Ni mogoče posodobiti obsega zveznosti nadaljnjih lastnosti {property}",
    "Add additional email" : "Dodaj dodaten elektronski naslov",
    "Add" : "Dodaj",
    "Create" : "Ustvari",
    "Change" : "Spreminjanje",
    "Delete" : "Izbriši",
    "Reshare" : "Nadaljnja souporaba",
    "School" : "Šola",
    "Default language" : "Privzeti jezik",
    "Common languages" : "Splošni jeziki",
    "Other languages" : "Drugi jeziki",
    "Password change is disabled because the master key is disabled" : "Spreminjanje gesla je onemogočeno, ker je onemogočen tudi glavni šifrirni ključ",
    "No accounts" : "Ni računov",
    "Loading accounts …" : "Poteka nalaganje računov ...",
    "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Seznam računov. Seznam zaradi zmogljivosti sistema ni v celoti prikazan. Podatki uporabnikov se nalagajo med pomikanjem po seznamu.",
    "Manager" : "Upravljalnik",
    "Account name will be autogenerated" : "iME RAČUNA bo samodejno ustvarjeno",
    "Account name (required)" : "Ime računa (zahtevano)",
    "New account" : "Nov račun",
    "Display name" : "Prikazno ime",
    "Either password or email is required" : "Zahtevano je ali geslo ali elektronski naslov",
    "Password (required)" : "Geslo (zahtevano)",
    "Email (required)" : "Elektronski naslov (zahtevano)",
    "Email" : "Elektronski naslov",
    "Member of the following groups" : "Član navedenih skupin",
    "Set account groups" : "Nastavi skupine računov",
    "Admin of the following groups" : "Skrbnik navedenih skupin",
    "Set account as admin for …" : "Nastavi račun kot skrbniški za ...",
    "Quota" : "Količinska omejitev",
    "Set account quota" : "Nastavi količinsko omejitev računa",
    "Language" : "Jezik",
    "Set default language" : "Nastavi privzeti jezik",
    "Add new account" : "Dodaj nov račun",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} račun ...","{userCount} računa ...","{userCount} računi ...","{userCount} računov ..."],
    "_{userCount} account_::_{userCount} accounts_" : ["{userCount} račun ...","{userCount} računa ...","{userCount} računi ...","{userCount} računov ..."],
    "Total rows summary" : "Skupni povzetek vrstic",
    "Scroll to load more rows" : "Podrsajte za nalaganje več vrstic",
    "Password or insufficient permissions message" : "Sporočilo gesla oziroma neustreznih dovoljenj",
    "Avatar" : "Podoba",
    "Account name" : "Ime računa",
    "Group admin for" : "Skrbnik skupine za",
    "Account backend" : "Ozadnji program računa",
    "Storage location" : "Mesto shrambe",
    "Last login" : "Zadnja prijava",
    "Account actions" : "Dejanja računa",
    "{size} used" : "V uporabi {size}·",
    "Delete account" : "Izbriši račun",
    "Disconnect all devices and delete local data" : "Odklopi vse naprave in izbriši krajevne podatke",
    "Disable account" : "Onemogoči račun",
    "Enable account" : "Omogoči račun",
    "Resend welcome email" : "Ponovno pošlji potrditveno sporočilo",
    "Remote wipe of devices" : "Oddaljeno varnostno brisanje naprav",
    "Wipe {userid}'s devices" : "Varnostno izbriši naprave uporabniškega računa {userid}",
    "Wiped {userid}'s devices" : "Varnostno izbrisane naprave računa {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Izbriši račun »{userid}« vključno z osebnimi podatki, datotekami, programi ...",
    "Account deletion" : "Brisanje računa",
    "Delete {userid}'s account" : "Izbriši račun {userid}",
    "Display name was successfully changed" : "Prikazno ime je uspešno zamenjano",
    "Password was successfully changed" : "Geslo je uspešno spremenjeno",
    "Email was successfully changed" : "Elektronski naslov je uspešno spremenjen",
    "Welcome mail sent!" : "Potrditveno sporočilo je poslano!",
    "Loading account …" : "Poteka nalaganje računa ...",
    "Change display name" : "Spremeni prikazno ime",
    "Set new password" : "Nastavi novo geslo",
    "You do not have permissions to see the details of this account" : "Ni ustreznih dovoljenj za pregled podrobnosti tega računa",
    "Set new email address" : "Nastavi nov elektronski naslov",
    "Add account to group" : "Dodaj račun v skupino",
    "Set account as admin for" : "Nastavi račun kot skrbniški za ...",
    "Select account quota" : "Nastavi količinsko omejitev računa",
    "Set the language" : "Nastavi jezik",
    "Toggle account actions menu" : "Preklopi meni dejanj računa",
    "Done" : "Končano",
    "Edit" : "Uredi",
    "Account management settings" : "Nastavitve upravljalnika računov",
    "Visibility" : "Vidnost",
    "Show language" : "Pokaži jezik",
    "Show account backend" : "Pokaži ozadnji program računa",
    "Show storage path" : "Pokaži pot mesta shrambe",
    "Show last login" : "Pokaži zadnjo prijavo",
    "Sorting" : "Razvrščanje",
    "Group list sorting" : "Razvrščanje seznama skupin",
    "By member count" : "Po številu članov",
    "By name" : "Po imenu",
    "Send email" : "Pošlji elektronsko sporočilo",
    "Send welcome email to new accounts" : "Pošlji sporočilo novim za nove račune",
    "Defaults" : "Privzeto",
    "Default quota" : "Privzeta omejitev",
    "Select default quota" : "Izbor količinske omejitve",
    "Server error while trying to complete WebAuthn device registration" : "Prišlo je do strežniške napake med zaključevanjem vpisovanja naprave WebAuthn",
    "Passwordless authentication requires a secure connection." : "Brezgeselna overitev zahteva varno povezavo.",
    "Add WebAuthn device" : "Dodaj napravo WebAuthn",
    "Please authorize your WebAuthn device." : "Overite napravo WebAuthn",
    "Adding your device …" : "Poteka dodajanje naprave ..",
    "Unnamed device" : "Neimenovana naprava",
    "Passwordless Authentication" : "Brezgeselna overitev",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Nastavitev račun za brezgeselno overitev dostopa po standardu FIDO2.",
    "No devices configured." : "Ni nastavljenih naprav.",
    "The following devices are configured for your account:" : "Z vašim računom so povezane navedene naprave:",
    "Your browser does not support WebAuthn." : "Brskalnik ne podpira overitve WebAuthn.",
    "Security & setup warnings" : "Varnost in namestitvena opozorila",
    "All checks passed." : "Vsa preverjanja so uspešno zaključena.",
    "There are some errors regarding your setup." : "Med preverjanjem je bilo zaznanih nekaj napak namestitve.",
    "There are some warnings regarding your setup." : "Med preverjanjem je bilo zbranih nekaj opozoril.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Skrbnik lahko prilagodi možnosti souporabe. Več podrobnosti je zapisanih v dokumentaciji.",
    "You need to enable the File sharing App." : "Omogočiti je treba program Souporabe datotek.",
    "App Store" : "Programska trgovina",
    "Loading app list" : "Poteka nalaganje seznama programov ...",
    "Loading categories" : "Poteka nalaganje kategorij",
    "Developer documentation ↗" : "Dokumentacija za razvijalce ↗",
    "Version {version}, {license}-licensed" : "Različica {version}, z dovoljenjem {license}",
    "Apply" : "Uveljavi",
    "All accounts" : "Vsi računi",
    "Admins" : "Skrbniki",
    "Account group: {group}" : "Skupina računov: {group}",
    "Account management" : "Upravljanje z računi",
    "Sending…" : "Poteka pošiljanje ...",
    "Email sent" : "Elektronsko sporočilo je poslano",
    "Location" : "Trenutno mesto",
    "Profile picture" : "Slika profila",
    "About" : "O meni",
    "Date of birth" : "Datum rojstva",
    "Full name" : "Polno ime",
    "Additional email" : "Dodatni elektronski naslov",
    "Fediverse (e.g. Mastodon)" : "Fediverse (na primer Mastodon)",
    "Headline" : "Naslov",
    "Organisation" : "Ustanova",
    "Phone number" : "Telefonska številka",
    "Role" : "Vloga",
    "X (formerly Twitter)" : "X (prej Twitter)",
    "Website" : "Spletna stran",
    "Profile visibility" : "Vidnost profila",
    "Locale" : "Jezikovne nastavitve",
    "First day of week" : "Prvi dan tedna",
    "Discover" : "Predstavitve",
    "Your apps" : "Vsi programi",
    "Active apps" : "Zagnani programi",
    "Disabled apps" : "Onemogočeni programi",
    "Updates" : "Posodobitve",
    "App bundles" : "Paketi programov",
    "Featured apps" : "Predlagani programi",
    "Supported apps" : "Podprti programi",
    "Show to everyone" : "Pokaži vsem",
    "Show to logged in accounts only" : "Pokaži le prijavljenim računom",
    "Hide" : "Skrij",
    "Download and enable" : "Prejmi in omogoči",
    "Disable" : "Onemogoči",
    "Allow untested app" : "Omogoči nepreizkušen program",
    "The app will be downloaded from the App Store" : "Program bo prejet iz zbirke programov",
    "Unknown" : "Neznano",
    "Never" : "Nikoli",
    "Could not register device: Network error" : "Naprave ni mogoče vpisati: napaka omrežja",
    "Could not register device: Probably already registered" : "Naprave ni mogoče vpisati: najverjetneje je že vpisana",
    "Could not register device" : "Naprave ni mogoče vpisati",
    "An error occurred during the request. Unable to proceed." : "Med izvajanjem zahteve je prišlo do napake, zato ni mogoče nadaljevati.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Napaka: tega programa ni mogoče namestiti, ker povzroča nestabilnost strežnika.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Program je omogočen, vendar zahteva posodobitev. Po nekaj sekundah boste preusmerjeni na stran za posodobitev.",
    "Do you really want to wipe your data from this device?" : "Ali res želite varnostno izbrisati podatke s te naprave?",
    "Confirm wipe" : "Potrdi varnostno brisanje",
    "Could not delete the app token" : "Žetona programa ni mogoče izbrisati",
    "Error while wiping the device with the token" : "Napaka med varnostnim brisanjem naprave z žetonom",
    "Error while updating device token name" : "Napaka med posodabljanjem imena žetona naprave",
    "Error while updating device token scope" : "Napaka med posodabljanjem obsega žetona naprave",
    "Could not set group sorting" : "Ni mogoče nastaviti razvrščanja skupine",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Iz omrežja je bilo prejetih preveč zahtev. Če je to napaka, stopite v stik s skrbnikom, sicer pa poskusite spet kasneje.",
    "Error" : "Napaka",
    "Account documentation" : "Dokumentacija računa",
    "Administration documentation" : "Skrbniška dokumentacija",
    "Forum" : "Forum",
    "General documentation" : "Splošna dokumentacija",
    "Legal notice" : "Pravno obvestilo",
    "Privacy policy" : "Pravila zasebnosti",
    "None/STARTTLS" : "Brez/STARTTLS",
    "SSL" : "Protokol SSL",
    "Open documentation" : "Odprta dokumentacija",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Strežnik mora biti za pošiljanje sporočil ustrezno nastavljen. Velja tudi za pošiljanje povezav za ponastavitev gesla..",
    "Send mode" : "Način pošiljanja",
    "Encryption" : "Šifriranje",
    "Sendmail mode" : "Način sendmail",
    "From address" : "Naslov pošiljatelja",
    "Server address" : "Naslov strežnika",
    "Port" : "Vrata",
    "Authentication" : "Overitev",
    "Authentication required" : "Zahtevana je overitev",
    "Credentials" : "Poverila",
    "SMTP Login" : "Prijava SMTP",
    "SMTP Password" : "Geslo SMTP",
    "Save" : "Shrani",
    "Test and verify email settings" : "Preizkusi in overi nastavitve elektronske pošte",
    "Reasons to use Nextcloud in your organization" : "Razlogi za uporabo oblaka Nextcloud v vaši organizaciji",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Okolje razvija {communityopen}skupnost Nextcloud{linkclose}, {githubopen}izvorna koda{linkclose} pa je objavljena pod pogoji dovoljenja {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Spremljajte naš Facebook",
    "Follow us on X" : "Sledite nam na X",
    "Follow us on Mastodon" : "Sledite nam na Mastodon",
    "Check out our blog" : "Preverite naš blog",
    "Subscribe to our newsletter" : "Naročite se na novice",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Ta objava oblaka Nextcloud ne vključuje podpore in hipna obvestila niso na voljo.",
    "Use a second factor besides your password to increase security for your account." : "Ob geslu je priporočljivo uporabiti tudi drugo-stopenjsko overitev za večjo varnost računa.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Če uporabljate za povezavo z oblakom Nextcloud programe tretjih oseb, najprej ustvarite in nastavite gesla za vsak program, preden omogočite dvostopenjsko overitev.",
    "Logged in account must be a subadmin" : "Račun prijave mora imeti dovoljenja podpornega skrbnika",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Če želite omogočiti izvajanje tega preverjanja, je treba zagotoviti, da se spletni strežnik lahko poveže sam s seboj. Zato mora biti nastavljen za povezovanje z vsaj eno od določenih »varnih domen« (trusted_domains) ali naslovov za prepis »vmesnika ukazne vrstice« (overwrite.cli.url). Spodletelo preverjanje je lahko posledica neujemanja imen DNS na strani strežnika oziroma pravila požarnega zidu.",
    "File locking" : "Zaklepanje datotek",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Zaklepanje datotek je onemogočeno, kar lahko privede do različnih težav. V izogib zapletom je priporočljivo omogočiti možnost »filelocking.enabled« v datoteki config.php.",
    "The PHP memory limit is below the recommended value of %s." : "Omejitev pomnilnika PHP je pod priporočeno mejo %s.",
    "- The `%1$s` HTTP header does not contain `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "– Glava HTTP »%1$s« ne vključuje vrednosti »%2$s«. To predstavlja potencialno varnostno ali zasebnostno tveganje, zato je priporočljivo prilagoditi nastavitve.",
    "Set default expiration date for shares" : "Nastavi privzeti datuma poteka za mesta souporabe",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Če je omogočeno samodejno dopolnjevanje »v isti skupini«, ali pa »po telefonskem imeniku«, se zadetek pokaže, če je uporabnik v katerikoli od teh zbirk.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Dovoli samodejno dokončanje pri vnosu polnega imena ali elektronskega naslova (brez upoštevanja manjkajočega ujemanja s telefonskim imenikom in pripadnosti isti skupini)",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja Nextcloud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja Nextcoud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
    "Your biography" : "Biografija",
    "You are using <strong>{usage}</strong>" : "Uporabljate <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Uporabljate <strong>{usage}</strong> od <strong>{totalSpace}</strong> (<strong>{usageRelative} %</strong>)",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Možnost omogoča varnostno brisanje podatkov Nextcloud z vseh naprav, povezanih z uporabniškim računom {userid}. Možnost deluje le, če so naprave povezane v spletno omrežje. Brisanje z oddaljenih naprav je uporabno v primeru izgubljene naprave, ali na primer prekinitve sodelovanja v neki skupini.",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ta program ni označen kot skladen z nameščeno različico oblaka Nextcloud. Če nameravate nadaljevati, boste program lahko namestili, vendar ta morda ne bo deloval po pričakovanjih, ali pa bo vplival na stabilnost sistema.",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Zaradi varnosti in optimizacije delovanja je nujno, da je sistem posodobljen in pravilno nastavljen. Preverjanje poteka tako, da se nekateri preizkusi izvajajo sproti in samodejno. Več podrobnosti je zabeleženih v dokumentaciji. ",
    "Checking for system and security issues." : "Preverjanje sistemskih in varnostnih nastavitev.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Preverite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">namestitveno dokumentacijo ↗</a> in morebitne napake oziroma opozorila v <a href=\"%2$s\">sistemskem dnevniku</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Preverite lahko tudi varnost storitev Nextcloud s <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">preverjalnikom ↗</a>."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
